# compipe
Spinner is the generic term for the fictional flying cars used in the film Blade Runner. A Spinner can be driven as a ground-based vehicle, take off vertically, hover, and cruise using jet propulsion much like the Vertical Take-Off and Landing (VTOL) aircraft currently in use today. 
